/* This file is part of the avgbs2txt project.
 * For more information, please see <http://www.interlis.ch>.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package ch.ehi.avgbs2txt;

import ch.ehi.basics.logging.EhiLogger;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.HashMap;
import java.util.Iterator;
import ch.ehi.avgbs2txt.toTxt.TransferToTxt;

/** Main class of application.
 * @author ce
 * @version $Revision: 1.0 $ $Date: 07.02.2005 $
 */
public class Main {
	/** name of application as shown to user.
	 */
	public static final String APP_NAME="avgbs2txt";
	/** name of jar file.
	 */
	public static final String AVGBS2TXT_JAR="avgbs2txt.jar"; 
	private static String version=null;
	/** main program entry.
	 * @param args command line arguments.
	 */
	static public void main(String args[]){
		// arguments on export
		// - xml-file
		// - txt-file
		String avgbsFile=null;
		String txtFile=null;
		if(args.length==0){
			ch.ehi.avgbs2txt.gui.MainFrame.main(avgbsFile,txtFile);
			return;
		}
		int argi=0;
		boolean doGui=false;
		for(;argi<args.length;argi++){
			String arg=args[argi];
			if(arg.equals("-trace")){
				EhiLogger.getInstance().setTraceFilter(false); 
			}else if(arg.equals("-gui")){
				doGui=true;
			}else if(arg.equals("-version")){
				printVersion();
				return;
			}else if(arg.equals("-help")){
					printVersion ();
					System.err.println();
					printDescription ();
					System.err.println();
					printUsage ();
					System.err.println();
					System.err.println("OPTIONS");
					System.err.println();
					System.err.println("-gui                  start GUI.");
					System.err.println("-trace                enable trace messages.");
					System.err.println("-help                 Display this help text.");
					System.err.println("-version              Display the version of pmtexp.");
					System.err.println();
					return;
				
			}else if(arg.startsWith("-")){
				EhiLogger.logAdaption(arg+": unknown option; ignored");
			}else{
				break;
			}
		}
		if(doGui){
			if(argi<args.length){
				avgbsFile=args[argi];
				argi++;
			}
			if(argi<args.length){
				txtFile=args[argi];
				argi++;
			}
			if(argi<args.length){
				EhiLogger.logAdaption(APP_NAME+": wrong number of arguments; ignored");
			}
			ch.ehi.avgbs2txt.gui.MainFrame.main(avgbsFile,txtFile);
		}else{
			if(argi+2==args.length){
				avgbsFile=args[argi];
				txtFile=args[argi+1];
				runExport(avgbsFile,txtFile);
			}else{
				EhiLogger.logError(APP_NAME+": wrong number of arguments");
				return;
			}
		}
		
	}
	/** main workhorse function.
	 * @param avgbsFile name of xml file to be processed.
	 * @param txtFile name of output file to be written.
	 */
	public static void runExport(
			String avgbsFile,
			String txtFile
		) {
		if(avgbsFile==null  || avgbsFile.length()==0){
			EhiLogger.logError("no AVGBS file given");
			return;
		}
		if(txtFile==null  || txtFile.length()==0){
			EhiLogger.logError("no text file given");
			return;
		}
		EhiLogger.traceState("avgbsFile <"+avgbsFile+">");
		EhiLogger.traceState("txtFile <"+txtFile+">");
		
		
		// process data file
		EhiLogger.logState("process data...");
		try{
			TransferToTxt trsf=new TransferToTxt();
			trsf.doit(avgbsFile,txtFile);
			EhiLogger.logState("...conversion done");
		}catch(Throwable ex){
			EhiLogger.logError(ex);
		}
	}
	protected static void printVersion ()
	{
	  System.err.println("AVGBS transferfile conversion, Version "+getVersion());
	  System.err.println("  Developed by Eisenhut Informatik AG, CH-3401 Burgdorf");
	}


	protected static void printDescription ()
	{
	  System.err.println("DESCRIPTION");
	  System.err.println("  Reads AVGBS data from a XML file and converts it to a plain text file.");
	}


	protected static void printUsage()
	{
	  System.err.println ("USAGE");
	  System.err.println("  java -jar avgbs2txt.jar [Options] [in.xml out.txt]");
	}
	/** get version of program.
	 * @return version e.g. "avgbs2txt-1.0.0"
	 */
	public static String getVersion() {
		  if(version==null){
//		java.util.ResourceBundle resVersion = java.util.ResourceBundle.getBundle(ch.ehi.basics.i18n.ResourceBundle.class2packagePath(Main.class)+"/Version");
		java.util.ResourceBundle resVersion = java.util.ResourceBundle.getBundle("ch.ehi.avgbs2txt.Version");
			// Major version numbers identify significant functional changes.
			// Minor version numbers identify smaller extensions to the functionality.
			// Micro versions are even finer grained versions.
			StringBuffer ret=new StringBuffer(20);
		ret.append(resVersion.getString("versionMajor"));
			ret.append('.');
		ret.append(resVersion.getString("versionMinor"));
			ret.append('.');
		ret.append(resVersion.getString("versionMicro"));
			ret.append('-');
		ret.append(resVersion.getString("versionDate"));
			version=ret.toString();
		  }
		  return version;
	}
}
